==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/ComponentParticipantSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.C_CSet;
import io.ciera.tool.sql.ooaofooa.component.impl.C_CSetImpl;
import io.ciera.tool.sql.ooaofooa.interaction.ComponentParticipant;
import io.ciera.tool.sql.ooaofooa.interaction.ComponentParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.InteractionParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InteractionParticipantSetImpl;

import java.util.Arrays;
import java.util.List;


public class ComponentParticipantSetImpl extends InstanceSet<ComponentParticipantSet,ComponentParticipant> implements ComponentParticipantSet {

    // attributes
    @Override
    public void setComponent_Id( UniqueId ref_Component_Id ) throws XtumlException {
        for ( ComponentParticipant componentparticipant : this ) componentparticipant.setComponent_Id( ref_Component_Id );
    }
    @Override
    public void setPart_ID( UniqueId ref_Part_ID ) throws XtumlException {
        for ( ComponentParticipant componentparticipant : this ) componentparticipant.setPart_ID( ref_Part_ID );
    }
    @Override
    public void setInformalComponentName( String m_InformalComponentName ) throws XtumlException {
        for ( ComponentParticipant componentparticipant : this ) componentparticipant.setInformalComponentName( m_InformalComponentName );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ComponentParticipant componentparticipant : this ) componentparticipant.setDescrip( m_Descrip );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( ComponentParticipant componentparticipant : this ) componentparticipant.setLabel( m_Label );
    }
    @Override
    public void setIsFormal( boolean m_isFormal ) throws XtumlException {
        for ( ComponentParticipant componentparticipant : this ) componentparticipant.setIsFormal( m_isFormal );
    }


    // selections
    @Override
    public InteractionParticipantSet R930_is_a_InteractionParticipant() throws XtumlException {
        InteractionParticipantSet interactionparticipantset = new InteractionParticipantSetImpl();
        for ( ComponentParticipant componentparticipant : this ) interactionparticipantset.add( componentparticipant.R930_is_a_InteractionParticipant() );
        return interactionparticipantset;
    }
    @Override
    public C_CSet R955_represents_C_C() throws XtumlException {
        C_CSet c_cset = new C_CSetImpl();
        for ( ComponentParticipant componentparticipant : this ) c_cset.add( componentparticipant.R955_represents_C_C() );
        return c_cset;
    }


    @Override
    public ComponentParticipant nullElement() {
        return ComponentParticipantImpl.EMPTY_COMPONENTPARTICIPANT;
    }

    @Override
    public ComponentParticipantSet emptySet() {
      return new ComponentParticipantSetImpl();
    }

    @Override
    public ComponentParticipantSet value() {
        return this;
    }

    @Override
    public List<ComponentParticipant> elements() {
        return Arrays.asList(toArray(new ComponentParticipant[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/ComponentParticipantSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.C_CSet;
import io.ciera.tool.sql.ooaofooa.component.impl.C_CSetImpl;
import io.ciera.tool.sql.ooaofooa.interaction.ComponentParticipant;
import io.ciera.tool.sql.ooaofooa.interaction.ComponentParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.InteractionParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InteractionParticipantSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ComponentParticipantSetImpl extends InstanceSet<ComponentParticipantSet,ComponentParticipant> implements ComponentParticipantSet {

    public ComponentParticipantSetImpl() {
    }

    public ComponentParticipantSetImpl(Comparator<? super ComponentParticipant> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ComponentParticipant componentparticipant : this ) componentparticipant.setDescrip( m_Descrip );
    }
    @Override
    public void setInformalComponentName( String m_InformalComponentName ) throws XtumlException {
        for ( ComponentParticipant componentparticipant : this ) componentparticipant.setInformalComponentName( m_InformalComponentName );
    }
    @Override
    public void setPart_ID( UniqueId ref_Part_ID ) throws XtumlException {
        for ( ComponentParticipant componentparticipant : this ) componentparticipant.setPart_ID( ref_Part_ID );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( ComponentParticipant componentparticipant : this ) componentparticipant.setLabel( m_Label );
    }
    @Override
    public void setIsFormal( boolean m_isFormal ) throws XtumlException {
        for ( ComponentParticipant componentparticipant : this ) componentparticipant.setIsFormal( m_isFormal );
    }
    @Override
    public void setComponent_Id( UniqueId ref_Component_Id ) throws XtumlException {
        for ( ComponentParticipant componentparticipant : this ) componentparticipant.setComponent_Id( ref_Component_Id );
    }


    // selections
    @Override
    public InteractionParticipantSet R930_is_a_InteractionParticipant() throws XtumlException {
        InteractionParticipantSet interactionparticipantset = new InteractionParticipantSetImpl();
        for ( ComponentParticipant componentparticipant : this ) interactionparticipantset.add( componentparticipant.R930_is_a_InteractionParticipant() );
        return interactionparticipantset;
    }
    @Override
    public C_CSet R955_represents_C_C() throws XtumlException {
        C_CSet c_cset = new C_CSetImpl();
        for ( ComponentParticipant componentparticipant : this ) c_cset.add( componentparticipant.R955_represents_C_C() );
        return c_cset;
    }


    @Override
    public ComponentParticipant nullElement() {
        return ComponentParticipantImpl.EMPTY_COMPONENTPARTICIPANT;
    }

    @Override
    public ComponentParticipantSet emptySet() {
      return new ComponentParticipantSetImpl();
    }

    @Override
    public ComponentParticipantSet emptySet(Comparator<? super ComponentParticipant> comp) {
      return new ComponentParticipantSetImpl(comp);
    }

    @Override
    public ComponentParticipantSet value() {
        return this;
    }

    @Override
    public List<ComponentParticipant> elements() {
        return Arrays.asList(toArray(new ComponentParticipant[0]));
    }

}
